@@ -7,6 +7,11 @@ if (require("testthat", quietly = TRUE)) {
 	#library(pkg, character.only = TRUE)
 	#test_package(pkg)
 	test_check(pkg)
+	if (testthat:::on_cran()) {
+	  # delete the tmpdir()/REddyProdExamples to avoid note on detritus in the temp directory
+	  # do not delete it outside cran, to avoid downloading several times
+	  unlink(getREddyProcExampleDir(), recursive=TRUE)
+	}
 } else {
 	warning("cannot run unit tests -- package testthat is not available")
 }
